==> gmt_6.5.0+dfsg.orig.tar.xz: gmt-6.5.0/src/gmt_cpt_masters.h <==
"gmt/abyss          : Black/dark blue to lightblue for bathymetry [R=-8000/0, C=RGB]",
"gmt/bathy          : Like abyss but via aquamarine at mid-depths [R=-8000/0, C=RGB]",
"gmt/categorical    : Color table particularly suitable for categorical data [C=RGB]",
"gmt/cyclic         : Cyclic colormap, spans 360 degrees of hue [C=HSV]",
"gmt/dem2           : Digital Elevation Model (DEM) scale by Dewez/Wessel [R=0/4900, C=RGB]",
"gmt/dem3           : Digital Elevation Model (DEM) scale by Paul Wessel [R=0/6000, C=RGB]",
"gmt/drywet         : Goes from dry to wet colors [C=RGB]",
"gmt/earth          : Colors for global bathymetry/topography relief [R=-11000/9000, H, C=RGB]",
"gmt/etopo1         : Colormap used in the ETOPO1 global relief map [R=-11000/8500, H, C=RGB]",
"gmt/gebco          : Colors for GEBCO bathymetric charts [R=-7000/0, C=RGB]",
"gmt/geo            : Colors for global bathymetry/topography relief [R=-8000/8000, H, C=RGB]",
"gmt/globe          : Colors for global bathymetry/topography relief [R=-10000/10000, H, C=RGB]",
"gmt/gray           : Gray linear ramp from black to white [C=RGB]",
"gmt/haxby          : Bill Haxby's color scheme for geoid & gravity [C=RGB]",
"gmt/ibcso          : The IBCSO bathymetry colors [R=-12000/0, C=RGB]",
"gmt/mag            : Colors for magnetic anomaly maps [R=-2000/2000, H, C=RGB]",
"gmt/nighttime      : Colors for DMSP-OLS Nighttime Lights Time Series [C=HSV]",
"gmt/no_green       : For those who hate green [S, C=RGB]",
"gmt/ocean          : White-green-blue bathymetry scale [R=-8000/0, C=RGB]",
"gmt/paired         : Categorical color map with 6 pairs of colors [C=RGB]",
"gmt/rainbow        : Rainbow, magenta-blue-cyan-green-yellow-red [C=HSV]",
"gmt/red2green      : Polar scale from red to green via white [S, C=RGB]",
"gmt/relief         : Wessel/Martinez colors for topography [R=-8000/+8000, H, C=RGB]",
"gmt/rust2silver    : USGS color map for planets such as Mercury [R=-5500/5500, C=RGB]",
"gmt/seafloor       : Purple-blue-white bathymetry scale [R=-6000/0, C=RGB]",
"gmt/sealand        : Smith bathymetry/topography scale [R=-6000/+3000, H, C=HSV]",
"gmt/seis           : R-O-Y-G-B seismic tomography colors [C=RGB]",
"gmt/split          : Like polar, but via black instead of white [S, C=RGB]",
"gmt/srtm           : Like dem2, but with blue for oceans [H, C=RGB]",
"gmt/terra          : Colors for global bathymetry/topography relief [R=-7000/7000, H, C=RGB]",
"gmt/topo           : Sandwell/Anderson colors for topography [R=-7000/+7000, H, C=HSV]",
"gmt/world          : Colors for global bathymetry/topography relief [R=-7000/7000, H, C=RGB]",
"gmt/wysiwyg        : 20 well-separated RGB colors [C=RGB]",
"SCM/acton          : Perceptually uniform sequential colormap, by Fabio Crameri [C=RGB]",
"SCM/actonS         : Perceptually uniform sequential categorical colormap, by Fabio Crameri [C=RGB]",
"SCM/bam            : Perceptually uniform bimodal colormap, light, by Fabio Crameri [C=RGB]",
"SCM/bamO           : Perceptually uniform bimodal cyclic colormap, light, by Fabio Crameri [C=RGB]",
"SCM/bamako         : Perceptually uniform, low-lightness gradient colormap by Fabio Crameri [C=RGB]",
"SCM/bamakoS        : Perceptually uniform, low-lightness gradient categorical colormap by Fabio Crameri [C=RGB]",
"SCM/batlow         : Perceptually uniform sequential \'rainbow\' colormap by, Fabio Crameri [C=RGB]",
"SCM/batlowK        : Perceptually uniform \'rainbow\' colormap with black ending by Fabio Crameri [C=RGB]",
"SCM/batlowS        : Perceptually uniform \'rainbow\' categorical colormap by Fabio Crameri [C=RGB]",
"SCM/batlowW        : Perceptually uniform \'rainbow\' colormap with white ending by Fabio Crameri [C=RGB]",
"SCM/berlin         : Perceptually uniform bimodal colormap, dark, by Fabio Crameri [S, C=RGB]",
"SCM/bilbao         : Perceptually uniform colormap by Fabio Crameri [C=RGB]",
"SCM/bilbaoS        : Perceptually uniform categorical colormap by Fabio Crameri [C=RGB]",
"SCM/broc           : Perceptually uniform bimodal colormap, light, by Fabio Crameri [S, C=RGB]",
"SCM/brocO          : Perceptually uniform bimodal cyclic colormap, light, by Fabio Crameri [C=RGB]",
"SCM/buda           : Perceptually uniform, low-lightness gradient colormap, by Fabio Crameri [C=RGB]",
"SCM/budaS          : Perceptually uniform, low-lightness gradient categorical colormap, by Fabio Crameri [C=RGB]",
"SCM/bukavu         : Perceptually uniform multi-sequential colormap by Fabio Crameri [H,C=RGB]",
"SCM/cork           : Perceptually uniform bimodal colormap, light, by Fabio Crameri [S, C=RGB]",
"SCM/corkO          : Perceptually uniform bimodal cyclic colormap, light, by Fabio Crameri [C=RGB]",
"SCM/davos          : Perceptually uniform colormap by Fabio Crameri [C=RGB]",
"SCM/davosS         : Perceptually uniform categorical colormap by Fabio Crameri [C=RGB]",
"SCM/devon          : Perceptually uniform sequential colormap, by Fabio Crameri [C=RGB]",
"SCM/devonS         : Perceptually uniform sequential categorical colormap, by Fabio Crameri [C=RGB]",
"SCM/fes            : Perceptually uniform multi-sequential colormap by Fabio Crameri [H,C=RGB]",
"SCM/glasgow        : Perceptually uniform sequential colormap by Fabio Crameri [C=RGB]",
"SCM/grayC          : Perceptually uniform \'gray\' colormap, by Fabio Crameri [C=RGB]",
"SCM/grayCS         : Perceptually uniform \'gray\' categorical colormap by Fabio Crameri [C=RGB]",
"SCM/hawaii         : Perceptually uniform sequential colormap, by Fabio Crameri [C=RGB]",
"SCM/hawaiiS        : Perceptually uniform lush categorical colormap by Fabio Crameri [C=RGB]",
"SCM/imola          : Perceptually uniform, low-lightness gradient colormap, by Fabio Crameri [C=RGB]",
"SCM/imolaS         : Perceptually uniform, low-lightness gradient categorical colormap, by Fabio Crameri [C=RGB]",
"SCM/lajolla        : Perceptually uniform colormap, without black or white, by Fabio Crameri [C=RGB]",
"SCM/lajollaS       : Perceptually uniform categorical colormap, without black or white, by Fabio Crameri [C=RGB]",
"SCM/lapaz          : Perceptually uniform \'rainbow\' colormap, by Fabio Crameri [C=RGB]",
"SCM/lapazS         : Perceptually uniform \'rainbow\' categorical colormap by Fabio Crameri [C=RGB]",
"SCM/lipari         : Perceptually uniform sequential colormap by Fabio Crameri [C=RGB]",
"SCM/lisbon         : Perceptually uniform bimodal colormap, dark, by Fabio Crameri [S, C=RGB]",
"SCM/managua        : Perceptually uniform diverging colormap, by Fabio Crameri [S,C=RGB]",
"SCM/navia          : Perceptually uniform sequential colormap by Fabio Crameri [C=RGB]",
"SCM/nuuk           : Perceptually uniform, low-lightness gradient colormap, by Fabio Crameri [C=RGB]",
"SCM/nuukS          : Perceptually uniform, low-lightness gradient categorical colormap, by Fabio Crameri [C=RGB]",
"SCM/oleron         : Perceptually uniform topography colormap, by Fabio Crameri [H, C=RGB]",
"SCM/oslo           : Perceptually uniform, black & white limits, by Fabio Crameri [C=RGB]",
"SCM/osloS          : Perceptually uniform, B&W limits, categorical colormap, by Fabio Crameri [C=RGB]",
"SCM/roma           : Perceptually uniform \'seis\' colormap, by Fabio Crameri [S, C=RGB]",
"SCM/romaO          : Perceptually uniform cyclic colormap by Fabio Crameri [C=RGB]",
"SCM/tofino         : Perceptually uniform bimodal colormap, dark, by Fabio Crameri [S, C=RGB]",
"SCM/tokyo          : Perceptually uniform colormap without black or white, by Fabio Crameri [C=RGB]",
"SCM/tokyoS         : Perceptually uniform categorical colormap without black or white, by Fabio Crameri [C=RGB]",
"SCM/turku          : Perceptually uniform colormap by Fabio Crameri [C=RGB]",
"SCM/turkuS         : Perceptually uniform categorical colormap by Fabio Crameri [C=RGB]",
"SCM/vanimo         : Perceptually uniform bimodal colormap, dark, by Fabio Crameri [C=RGB]",
"SCM/vik            : Perceptually uniform bimodal colormap, light, by Fabio Crameri [S, C=RGB]",
"SCM/vikO           : Perceptually uniform bimodal cyclic colormap, light, by Fabio Crameri [C=RGB]",
"cmocean/algae      : Perceptually uniform colormap, by Kirsten Thyng [C=RGB]",
"cmocean/amp        : Perceptually uniform colormap, by Kirsten Thyng [C=RGB]",
"cmocean/balance    : Perceptually uniform divergent colormap, by Kirsten Thyng [S,C=RGB]",
"cmocean/curl       : Perceptually uniform divergent colormap, by Kirsten Thyng [S,C=RGB]",
"cmocean/deep       : Perceptually uniform colormap, by Kirsten Thyng [C=RGB]",
"cmocean/delta      : Perceptually uniform divergent colormap, by Kirsten Thyng [S,C=RGB]",
"cmocean/dense      : Perceptually uniform colormap, by Kirsten Thyng [C=RGB]",
"cmocean/diff       : Perceptually uniform divergent colormap, by Kirsten Thyng [S,C=RGB]",
"cmocean/gray       : Perceptually uniform grayscale map, by Kirsten Thyng [C=RGB]",
"cmocean/haline     : Perceptually uniform colormap, by Kirsten Thyng [C=RGB]",
"cmocean/ice        : Perceptually uniform colormap, by Kirsten Thyng [C=RGB]",
"cmocean/matter     : Perceptually uniform colormap, by Kirsten Thyng [C=RGB]",
"cmocean/oxy        : Perceptually uniform divergent colormap, by Kirsten Thyng [C=RGB]",
"cmocean/phase      : Perceptually uniform cyclic colormap, by Kirsten Thyng [O,C=RGB]",
"cmocean/rain       : Perceptually uniform colormap, by Kirsten Thyng [C=RGB]",
"cmocean/solar      : Perceptually uniform colormap, by Kirsten Thyng [C=RGB]",
"cmocean/speed      : Perceptually uniform colormap, by Kirsten Thyng [C=RGB]",
"cmocean/tarn       : Perceptually uniform colormap, by Kirsten Thyng [S,C=RGB]",
"cmocean/tempo      : Perceptually uniform colormap, by Kirsten Thyng [C=RGB]",
"cmocean/thermal    : Perceptually uniform colormap, by Kirsten Thyng [C=RGB]",
"cmocean/topo       : Perceptually uniform colormap, by Kirsten Thyng [H,C=RGB]",
"cmocean/turbid     : Perceptually uniform colormap, by Kirsten Thyng [C=RGB]",
"cpt-city/cubhelix  : Intensity colormap via cube helix by Dave Green [C=RGB]",
"cpt-city/dem1      : Digital Elevation Model (DEM) scale by Thomas Dewez [R=0/800, C=RGB]",
"cpt-city/dem4      : Digital Elevation Model (DEM) scale for Wikipedia figures [R=0/1500, C=RGB]",
"cpt-city/elevation : Washed-out colors for topography [R=0/7000, C=RGB]",
"google/turbo       : Google's Improved Rainbow Colormap for Visualization [C=RGB]",
"matlab/cool        : Linear change from blue to magenta [C=RGB]",
"matlab/copper      : Dark to light copper brown [C=RGB]",
"matlab/hot         : Black through red and yellow to white [C=RGB]",
"matlab/jet         : Dark to light blue, white, yellow and red [C=RGB]",
"matlab/polar       : Blue via white to red [S, C=RGB]",
"matplotlib/inferno : New colormap Option B from matplotlib [C=RGB]",
"matplotlib/magma   : New colormap Option A from matplotlib [C=RGB]",
"matplotlib/plasma  : New colormap Option C from matplotlib [C=RGB]",
"matplotlib/viridis : New colormap Option D from matplotlib [C=RGB]",
"panoply/panoply    : Default colormap from the Panoply application [C=RGB]",

==> gmt_6.6.0+dfsg.orig.tar.xz: gmt-6.6.0/src/gmt_cpt_masters.h <==
"gmt/abyss          : Black/dark blue to lightblue for bathymetry [R=-8000/0, C=RGB]",
"gmt/bathy          : Like abyss but via aquamarine at mid-depths [R=-8000/0, C=RGB]",
"gmt/categorical    : Color table particularly suitable for categorical data [C=RGB]",
"gmt/cyclic         : Cyclic colormap, spans 360 degrees of hue [C=HSV]",
"gmt/dem2           : Digital Elevation Model (DEM) scale by Dewez/Wessel [R=0/4900, C=RGB]",
"gmt/dem3           : Digital Elevation Model (DEM) scale by Paul Wessel [R=0/6000, C=RGB]",
"gmt/drywet         : Goes from dry to wet colors [C=RGB]",
"gmt/earth          : Colors for global bathymetry/topography relief [R=-11000/9000, H, C=RGB]",
"gmt/etopo1         : Colormap used in the ETOPO1 global relief map [R=-11000/8500, H, C=RGB]",
"gmt/gebco          : Colors for GEBCO bathymetric charts [R=-7000/0, C=RGB]",
"gmt/geo            : Colors for global bathymetry/topography relief [R=-8000/8000, H, C=RGB]",
"gmt/globe          : Colors for global bathymetry/topography relief [R=-10000/10000, H, C=RGB]",
"gmt/gray           : Gray linear ramp from black to white [C=RGB]",
"gmt/haxby          : Bill Haxby's color scheme for geoid & gravity [C=RGB]",
"gmt/ibcso          : The IBCSO bathymetry colors [R=-12000/0, C=RGB]",
"gmt/mag            : Colors for magnetic anomaly maps [R=-2000/2000, H, C=RGB]",
"gmt/nighttime      : Colors for DMSP-OLS Nighttime Lights Time Series [C=HSV]",
"gmt/no_green       : For those who hate green [S, C=RGB]",
"gmt/ocean          : White-green-blue bathymetry scale [R=-8000/0, C=RGB]",
"gmt/paired         : Categorical color map with 6 pairs of colors [C=RGB]",
"gmt/rainbow        : Rainbow, magenta-blue-cyan-green-yellow-red [C=HSV]",
"gmt/red2green      : Polar scale from red to green via white [S, C=RGB]",
"gmt/relief         : Wessel/Martinez colors for topography [R=-8000/+8000, H, C=RGB]",
"gmt/rust2silver    : USGS color map for planets such as Mercury [R=-5500/5500, C=RGB]",
"gmt/seafloor       : Purple-blue-white bathymetry scale [R=-6000/0, C=RGB]",
"gmt/sealand        : Smith bathymetry/topography scale [R=-6000/+3000, H, C=HSV]",
"gmt/seis           : R-O-Y-G-B seismic tomography colors [C=RGB]",
"gmt/split          : Like polar, but via black instead of white [S, C=RGB]",
"gmt/srtm           : Like dem2, but with blue for oceans [H, C=RGB]",
"gmt/terra          : Colors for global bathymetry/topography relief [R=-7000/7000, H, C=RGB]",
"gmt/topo           : Sandwell/Anderson colors for topography [R=-7000/+7000, H, C=HSV]",
"gmt/world          : Colors for global bathymetry/topography relief [R=-7000/7000, H, C=RGB]",
"gmt/wysiwyg        : 20 well-separated RGB colors [C=RGB]",
"SCM/acton          : Perceptually uniform sequential colormap, by Fabio Crameri [C=RGB]",
"SCM/actonS         : Perceptually uniform sequential categorical colormap, by Fabio Crameri [C=RGB]",
"SCM/bam            : Perceptually uniform bimodal colormap, light, by Fabio Crameri [C=RGB]",
"SCM/bamO           : Perceptually uniform bimodal cyclic colormap, light, by Fabio Crameri [C=RGB]",
"SCM/bamako         : Perceptually uniform, low-lightness gradient colormap by Fabio Crameri [C=RGB]",
"SCM/bamakoS        : Perceptually uniform, low-lightness gradient categorical colormap by Fabio Crameri [C=RGB]",
"SCM/batlow         : Perceptually uniform sequential \'rainbow\' colormap by, Fabio Crameri [C=RGB]",
"SCM/batlowK        : Perceptually uniform \'rainbow\' colormap with black ending by Fabio Crameri [C=RGB]",
"SCM/batlowS        : Perceptually uniform \'rainbow\' categorical colormap by Fabio Crameri [C=RGB]",
"SCM/batlowW        : Perceptually uniform \'rainbow\' colormap with white ending by Fabio Crameri [C=RGB]",
"SCM/berlin         : Perceptually uniform bimodal colormap, dark, by Fabio Crameri [S, C=RGB]",
"SCM/bilbao         : Perceptually uniform colormap by Fabio Crameri [C=RGB]",
"SCM/bilbaoS        : Perceptually uniform categorical colormap by Fabio Crameri [C=RGB]",
"SCM/broc           : Perceptually uniform bimodal colormap, light, by Fabio Crameri [S, C=RGB]",
"SCM/brocO          : Perceptually uniform bimodal cyclic colormap, light, by Fabio Crameri [C=RGB]",
"SCM/buda           : Perceptually uniform, low-lightness gradient colormap, by Fabio Crameri [C=RGB]",
"SCM/budaS          : Perceptually uniform, low-lightness gradient categorical colormap, by Fabio Crameri [C=RGB]",
"SCM/bukavu         : Perceptually uniform multi-sequential colormap by Fabio Crameri [H,C=RGB]",
"SCM/cork           : Perceptually uniform bimodal colormap, light, by Fabio Crameri [S, C=RGB]",
"SCM/corkO          : Perceptually uniform bimodal cyclic colormap, light, by Fabio Crameri [C=RGB]",
"SCM/davos          : Perceptually uniform colormap by Fabio Crameri [C=RGB]",
"SCM/davosS         : Perceptually uniform categorical colormap by Fabio Crameri [C=RGB]",
"SCM/devon          : Perceptually uniform sequential colormap, by Fabio Crameri [C=RGB]",
"SCM/devonS         : Perceptually uniform sequential categorical colormap, by Fabio Crameri [C=RGB]",
"SCM/fes            : Perceptually uniform multi-sequential colormap by Fabio Crameri [H,C=RGB]",
"SCM/glasgow        : Perceptually uniform sequential colormap by Fabio Crameri [C=RGB]",
"SCM/grayC          : Perceptually uniform \'gray\' colormap, by Fabio Crameri [C=RGB]",
"SCM/grayCS         : Perceptually uniform \'gray\' categorical colormap by Fabio Crameri [C=RGB]",
"SCM/hawaii         : Perceptually uniform sequential colormap, by Fabio Crameri [C=RGB]",
"SCM/hawaiiS        : Perceptually uniform lush categorical colormap by Fabio Crameri [C=RGB]",
"SCM/imola          : Perceptually uniform, low-lightness gradient colormap, by Fabio Crameri [C=RGB]",
"SCM/imolaS         : Perceptually uniform, low-lightness gradient categorical colormap, by Fabio Crameri [C=RGB]",
"SCM/lajolla        : Perceptually uniform colormap, without black or white, by Fabio Crameri [C=RGB]",
"SCM/lajollaS       : Perceptually uniform categorical colormap, without black or white, by Fabio Crameri [C=RGB]",
"SCM/lapaz          : Perceptually uniform \'rainbow\' colormap, by Fabio Crameri [C=RGB]",
"SCM/lapazS         : Perceptually uniform \'rainbow\' categorical colormap by Fabio Crameri [C=RGB]",
"SCM/lipari         : Perceptually uniform sequential colormap by Fabio Crameri [C=RGB]",
"SCM/lisbon         : Perceptually uniform bimodal colormap, dark, by Fabio Crameri [S, C=RGB]",
"SCM/managua        : Perceptually uniform diverging colormap, by Fabio Crameri [S,C=RGB]",
"SCM/navia          : Perceptually uniform sequential colormap by Fabio Crameri [C=RGB]",
"SCM/naviaW         : Perceptually uniform sequential colormap with white ending by Fabio Crameri [C=RGB]",
"SCM/nuuk           : Perceptually uniform, low-lightness gradient colormap, by Fabio Crameri [C=RGB]",
"SCM/nuukS          : Perceptually uniform, low-lightness gradient categorical colormap, by Fabio Crameri [C=RGB]",
"SCM/oleron         : Perceptually uniform topography colormap, by Fabio Crameri [H, C=RGB]",
"SCM/oslo           : Perceptually uniform, black & white limits, by Fabio Crameri [C=RGB]",
"SCM/osloS          : Perceptually uniform, B&W limits, categorical colormap, by Fabio Crameri [C=RGB]",
"SCM/roma           : Perceptually uniform \'seis\' colormap, by Fabio Crameri [S, C=RGB]",
"SCM/romaO          : Perceptually uniform cyclic colormap by Fabio Crameri [C=RGB]",
"SCM/tofino         : Perceptually uniform bimodal colormap, dark, by Fabio Crameri [S, C=RGB]",
"SCM/tokyo          : Perceptually uniform colormap without black or white, by Fabio Crameri [C=RGB]",
"SCM/tokyoS         : Perceptually uniform categorical colormap without black or white, by Fabio Crameri [C=RGB]",
"SCM/turku          : Perceptually uniform colormap by Fabio Crameri [C=RGB]",
"SCM/turkuS         : Perceptually uniform categorical colormap by Fabio Crameri [C=RGB]",
"SCM/vanimo         : Perceptually uniform bimodal colormap, dark, by Fabio Crameri [C=RGB]",
"SCM/vik            : Perceptually uniform bimodal colormap, light, by Fabio Crameri [S, C=RGB]",
"SCM/vikO           : Perceptually uniform bimodal cyclic colormap, light, by Fabio Crameri [C=RGB]",
"cmocean/algae      : Perceptually uniform colormap, by Kirsten Thyng [C=RGB]",
"cmocean/amp        : Perceptually uniform colormap, by Kirsten Thyng [C=RGB]",
"cmocean/balance    : Perceptually uniform divergent colormap, by Kirsten Thyng [S,C=RGB]",
"cmocean/curl       : Perceptually uniform divergent colormap, by Kirsten Thyng [S,C=RGB]",
"cmocean/deep       : Perceptually uniform colormap, by Kirsten Thyng [C=RGB]",
"cmocean/delta      : Perceptually uniform divergent colormap, by Kirsten Thyng [S,C=RGB]",
"cmocean/dense      : Perceptually uniform colormap, by Kirsten Thyng [C=RGB]",
"cmocean/diff       : Perceptually uniform divergent colormap, by Kirsten Thyng [S,C=RGB]",
"cmocean/gray       : Perceptually uniform grayscale map, by Kirsten Thyng [C=RGB]",
"cmocean/haline     : Perceptually uniform colormap, by Kirsten Thyng [C=RGB]",
"cmocean/ice        : Perceptually uniform colormap, by Kirsten Thyng [C=RGB]",
"cmocean/matter     : Perceptually uniform colormap, by Kirsten Thyng [C=RGB]",
"cmocean/oxy        : Perceptually uniform divergent colormap, by Kirsten Thyng [C=RGB]",
"cmocean/phase      : Perceptually uniform cyclic colormap, by Kirsten Thyng [O,C=RGB]",
"cmocean/rain       : Perceptually uniform colormap, by Kirsten Thyng [C=RGB]",
"cmocean/solar      : Perceptually uniform colormap, by Kirsten Thyng [C=RGB]",
"cmocean/speed      : Perceptually uniform colormap, by Kirsten Thyng [C=RGB]",
"cmocean/tarn       : Perceptually uniform colormap, by Kirsten Thyng [S,C=RGB]",
"cmocean/tempo      : Perceptually uniform colormap, by Kirsten Thyng [C=RGB]",
"cmocean/thermal    : Perceptually uniform colormap, by Kirsten Thyng [C=RGB]",
"cmocean/topo       : Perceptually uniform colormap, by Kirsten Thyng [H,C=RGB]",
"cmocean/turbid     : Perceptually uniform colormap, by Kirsten Thyng [C=RGB]",
"cpt-city/cubhelix  : Intensity colormap via cube helix by Dave Green [C=RGB]",
"cpt-city/dem1      : Digital Elevation Model (DEM) scale by Thomas Dewez [R=0/800, C=RGB]",
"cpt-city/dem4      : Digital Elevation Model (DEM) scale for Wikipedia figures [R=0/1500, C=RGB]",
"cpt-city/elevation : Washed-out colors for topography [R=0/7000, C=RGB]",
"google/turbo       : Google's Improved Rainbow Colormap for Visualization [C=RGB]",
"matlab/cool        : Linear change from blue to magenta [C=RGB]",
"matlab/copper      : Dark to light copper brown [C=RGB]",
"matlab/hot         : Black through red and yellow to white [C=RGB]",
"matlab/jet         : Dark to light blue, white, yellow and red [C=RGB]",
"matlab/polar       : Blue via white to red [S, C=RGB]",
"matplotlib/inferno : New colormap Option B from matplotlib [C=RGB]",
"matplotlib/magma   : New colormap Option A from matplotlib [C=RGB]",
"matplotlib/plasma  : New colormap Option C from matplotlib [C=RGB]",
"matplotlib/viridis : New colormap Option D from matplotlib [C=RGB]",
"panoply/panoply    : Default colormap from the Panoply application [C=RGB]",
